# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/admin/participant/v30/package_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/admin/participant/v30/package_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCcom/digitalasset/canton/admin/participant/v30/package_service.proto\x12-com.digitalasset.canton.admin.participant.v30\x1a\x1bgoogle/protobuf/empty.proto\";\n\x1aListPackageContentsRequest\x12\x1d\n\npackage_id\x18\x01 \x01(\tR\tpackageId\"y\n\x1bListPackageContentsResponse\x12Z\n\x07modules\x18\x01 \x03(\x0b\x32@.com.digitalasset.canton.admin.participant.v30.ModuleDescriptionR\x07modules\"/\n\x16ListDarContentsRequest\x12\x15\n\x06\x64\x61r_id\x18\x01 \x01(\tR\x05\x64\x61rId\"\x8f\x01\n\x17ListDarContentsResponse\x12 \n\x0b\x64\x65scription\x18\x01 \x01(\tR\x0b\x64\x65scription\x12\x12\n\x04main\x18\x02 \x01(\tR\x04main\x12\x1a\n\x08packages\x18\x03 \x03(\tR\x08packages\x12\"\n\x0c\x64\x65pendencies\x18\x04 \x03(\tR\x0c\x64\x65pendencies\"K\n\x14RemovePackageRequest\x12\x1d\n\npackage_id\x18\x01 \x01(\tR\tpackageId\x12\x14\n\x05\x66orce\x18\x02 \x01(\x08R\x05\x66orce\"I\n\x15RemovePackageResponse\x12\x30\n\x07success\x18\x01 \x01(\x0b\x32\x16.google.protobuf.EmptyR\x07success\"L\n\rVetDarRequest\x12\x19\n\x08\x64\x61r_hash\x18\x01 \x01(\tR\x07\x64\x61rHash\x12 \n\x0bsynchronize\x18\x02 \x01(\x08R\x0bsynchronize\"\x10\n\x0eVetDarResponse\",\n\x0fUnvetDarRequest\x12\x19\n\x08\x64\x61r_hash\x18\x01 \x01(\tR\x07\x64\x61rHash\"\x12\n\x10UnvetDarResponse\"-\n\x10RemoveDarRequest\x12\x19\n\x08\x64\x61r_hash\x18\x01 \x01(\tR\x07\x64\x61rHash\"E\n\x11RemoveDarResponse\x12\x30\n\x07success\x18\x01 \x01(\x0b\x32\x16.google.protobuf.EmptyR\x07success\"\'\n\x11ModuleDescription\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\"+\n\x13ListPackagesRequest\x12\x14\n\x05limit\x18\x01 \x01(\x05R\x05limit\"\x8c\x01\n\x14ListPackagesResponse\x12t\n\x14package_descriptions\x18\x01 \x03(\x0b\x32\x41.com.digitalasset.canton.admin.participant.v30.PackageDescriptionR\x13packageDescriptions\"\'\n\x0fListDarsRequest\x12\x14\n\x05limit\x18\x01 \x01(\x05R\x05limit\"e\n\x10ListDarsResponse\x12Q\n\x04\x64\x61rs\x18\x01 \x03(\x0b\x32=.com.digitalasset.canton.admin.participant.v30.DarDescriptionR\x04\x64\x61rs\"8\n\x0e\x44\x61rDescription\x12\x12\n\x04hash\x18\x01 \x01(\tR\x04hash\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\"\x9d\x01\n\x10UploadDarRequest\x12\x12\n\x04\x64\x61ta\x18\x01 \x01(\x0cR\x04\x64\x61ta\x12\x1a\n\x08\x66ilename\x18\x02 \x01(\tR\x08\x66ilename\x12(\n\x10vet_all_packages\x18\x03 \x01(\x08R\x0evetAllPackages\x12/\n\x13synchronize_vetting\x18\x04 \x01(\x08R\x12synchronizeVetting\"\xaa\x02\n\x11UploadDarResponse\x12\x64\n\x07success\x18\x01 \x01(\x0b\x32H.com.digitalasset.canton.admin.participant.v30.UploadDarResponse.SuccessH\x00R\x07success\x12\x64\n\x07\x66\x61ilure\x18\x02 \x01(\x0b\x32H.com.digitalasset.canton.admin.participant.v30.UploadDarResponse.FailureH\x00R\x07\x66\x61ilure\x1a\x1d\n\x07Success\x12\x12\n\x04hash\x18\x01 \x01(\tR\x04hash\x1a!\n\x07\x46\x61ilure\x12\x16\n\x06reason\x18\x01 \x01(\tR\x06reasonB\x07\n\x05value\"D\n\x12ValidateDarRequest\x12\x12\n\x04\x64\x61ta\x18\x01 \x01(\x0cR\x04\x64\x61ta\x12\x1a\n\x08\x66ilename\x18\x02 \x01(\tR\x08\x66ilename\")\n\x13ValidateDarResponse\x12\x12\n\x04hash\x18\x01 \x01(\tR\x04hash\"#\n\rGetDarRequest\x12\x12\n\x04hash\x18\x01 \x01(\tR\x04hash\"8\n\x0eGetDarResponse\x12\x12\n\x04\x64\x61ta\x18\x01 \x01(\x0cR\x04\x64\x61ta\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\"b\n\x12PackageDescription\x12\x1d\n\npackage_id\x18\x01 \x01(\tR\tpackageId\x12-\n\x12source_description\x18\x03 \x01(\tR\x11sourceDescription2\xfe\x0c\n\x0ePackageService\x12\x97\x01\n\x0cListPackages\x12\x42.com.digitalasset.canton.admin.participant.v30.ListPackagesRequest\x1a\x43.com.digitalasset.canton.admin.participant.v30.ListPackagesResponse\x12\xac\x01\n\x13ListPackageContents\x12I.com.digitalasset.canton.admin.participant.v30.ListPackageContentsRequest\x1aJ.com.digitalasset.canton.admin.participant.v30.ListPackageContentsResponse\x12\x8b\x01\n\x08ListDars\x12>.com.digitalasset.canton.admin.participant.v30.ListDarsRequest\x1a?.com.digitalasset.canton.admin.participant.v30.ListDarsResponse\x12\xa0\x01\n\x0fListDarContents\x12\x45.com.digitalasset.canton.admin.participant.v30.ListDarContentsRequest\x1a\x46.com.digitalasset.canton.admin.participant.v30.ListDarContentsResponse\x12\x8e\x01\n\tUploadDar\x12?.com.digitalasset.canton.admin.participant.v30.UploadDarRequest\x1a@.com.digitalasset.canton.admin.participant.v30.UploadDarResponse\x12\x94\x01\n\x0bValidateDar\x12\x41.com.digitalasset.canton.admin.participant.v30.ValidateDarRequest\x1a\x42.com.digitalasset.canton.admin.participant.v30.ValidateDarResponse\x12\x9a\x01\n\rRemovePackage\x12\x43.com.digitalasset.canton.admin.participant.v30.RemovePackageRequest\x1a\x44.com.digitalasset.canton.admin.participant.v30.RemovePackageResponse\x12\x85\x01\n\x06VetDar\x12<.com.digitalasset.canton.admin.participant.v30.VetDarRequest\x1a=.com.digitalasset.canton.admin.participant.v30.VetDarResponse\x12\x8b\x01\n\x08UnvetDar\x12>.com.digitalasset.canton.admin.participant.v30.UnvetDarRequest\x1a?.com.digitalasset.canton.admin.participant.v30.UnvetDarResponse\x12\x8e\x01\n\tRemoveDar\x12?.com.digitalasset.canton.admin.participant.v30.RemoveDarRequest\x1a@.com.digitalasset.canton.admin.participant.v30.RemoveDarResponse\x12\x85\x01\n\x06GetDar\x12<.com.digitalasset.canton.admin.participant.v30.GetDarRequest\x1a=.com.digitalasset.canton.admin.participant.v30.GetDarResponseB^Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.admin.participant.v30.package_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30'
  _globals['_LISTPACKAGECONTENTSREQUEST']._serialized_start=147
  _globals['_LISTPACKAGECONTENTSREQUEST']._serialized_end=206
  _globals['_LISTPACKAGECONTENTSRESPONSE']._serialized_start=208
  _globals['_LISTPACKAGECONTENTSRESPONSE']._serialized_end=329
  _globals['_LISTDARCONTENTSREQUEST']._serialized_start=331
  _globals['_LISTDARCONTENTSREQUEST']._serialized_end=378
  _globals['_LISTDARCONTENTSRESPONSE']._serialized_start=381
  _globals['_LISTDARCONTENTSRESPONSE']._serialized_end=524
  _globals['_REMOVEPACKAGEREQUEST']._serialized_start=526
  _globals['_REMOVEPACKAGEREQUEST']._serialized_end=601
  _globals['_REMOVEPACKAGERESPONSE']._serialized_start=603
  _globals['_REMOVEPACKAGERESPONSE']._serialized_end=676
  _globals['_VETDARREQUEST']._serialized_start=678
  _globals['_VETDARREQUEST']._serialized_end=754
  _globals['_VETDARRESPONSE']._serialized_start=756
  _globals['_VETDARRESPONSE']._serialized_end=772
  _globals['_UNVETDARREQUEST']._serialized_start=774
  _globals['_UNVETDARREQUEST']._serialized_end=818
  _globals['_UNVETDARRESPONSE']._serialized_start=820
  _globals['_UNVETDARRESPONSE']._serialized_end=838
  _globals['_REMOVEDARREQUEST']._serialized_start=840
  _globals['_REMOVEDARREQUEST']._serialized_end=885
  _globals['_REMOVEDARRESPONSE']._serialized_start=887
  _globals['_REMOVEDARRESPONSE']._serialized_end=956
  _globals['_MODULEDESCRIPTION']._serialized_start=958
  _globals['_MODULEDESCRIPTION']._serialized_end=997
  _globals['_LISTPACKAGESREQUEST']._serialized_start=999
  _globals['_LISTPACKAGESREQUEST']._serialized_end=1042
  _globals['_LISTPACKAGESRESPONSE']._serialized_start=1045
  _globals['_LISTPACKAGESRESPONSE']._serialized_end=1185
  _globals['_LISTDARSREQUEST']._serialized_start=1187
  _globals['_LISTDARSREQUEST']._serialized_end=1226
  _globals['_LISTDARSRESPONSE']._serialized_start=1228
  _globals['_LISTDARSRESPONSE']._serialized_end=1329
  _globals['_DARDESCRIPTION']._serialized_start=1331
  _globals['_DARDESCRIPTION']._serialized_end=1387
  _globals['_UPLOADDARREQUEST']._serialized_start=1390
  _globals['_UPLOADDARREQUEST']._serialized_end=1547
  _globals['_UPLOADDARRESPONSE']._serialized_start=1550
  _globals['_UPLOADDARRESPONSE']._serialized_end=1848
  _globals['_UPLOADDARRESPONSE_SUCCESS']._serialized_start=1775
  _globals['_UPLOADDARRESPONSE_SUCCESS']._serialized_end=1804
  _globals['_UPLOADDARRESPONSE_FAILURE']._serialized_start=1806
  _globals['_UPLOADDARRESPONSE_FAILURE']._serialized_end=1839
  _globals['_VALIDATEDARREQUEST']._serialized_start=1850
  _globals['_VALIDATEDARREQUEST']._serialized_end=1918
  _globals['_VALIDATEDARRESPONSE']._serialized_start=1920
  _globals['_VALIDATEDARRESPONSE']._serialized_end=1961
  _globals['_GETDARREQUEST']._serialized_start=1963
  _globals['_GETDARREQUEST']._serialized_end=1998
  _globals['_GETDARRESPONSE']._serialized_start=2000
  _globals['_GETDARRESPONSE']._serialized_end=2056
  _globals['_PACKAGEDESCRIPTION']._serialized_start=2058
  _globals['_PACKAGEDESCRIPTION']._serialized_end=2156
  _globals['_PACKAGESERVICE']._serialized_start=2159
  _globals['_PACKAGESERVICE']._serialized_end=3821
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Checkpoint(_message.Message):
    __slots__ = ("record_time", "offset")
    RECORD_TIME_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    record_time: _timestamp_pb2.Timestamp
    offset: str
    def __init__(self, record_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., offset: _Optional[str] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from ...crypto.v0 import crypto_pb2 as _crypto_pb2
from ..v0 import participant_transaction_pb2 as _participant_transaction_pb2
from ..v1 import participant_transaction_pb2 as _participant_transaction_pb2_1
from ..v2 import participant_transaction_pb2 as _participant_transaction_pb2_1_1
from ..v3 import participant_transaction_pb2 as _participant_transaction_pb2_1_1_1
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ViewParticipantData(_message.Message):
    __slots__ = ("salt", "core_inputs", "created_core", "created_in_subview_archived_in_core", "resolved_keys", "action_description", "rollback_context")
    SALT_FIELD_NUMBER: _ClassVar[int]
    CORE_INPUTS_FIELD_NUMBER: _ClassVar[int]
    CREATED_CORE_FIELD_NUMBER: _ClassVar[int]
    CREATED_IN_SUBVIEW_ARCHIVED_IN_CORE_FIELD_NUMBER: _ClassVar[int]
    RESOLVED_KEYS_FIELD_NUMBER: _ClassVar[int]
    ACTION_DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    ROLLBACK_CONTEXT_FIELD_NUMBER: _ClassVar[int]
    salt: _crypto_pb2.Salt
    core_inputs: _containers.RepeatedCompositeFieldContainer[_participant_transaction_pb2_1_1.InputContract]
    created_core: _containers.RepeatedCompositeFieldContainer[_participant_transaction_pb2_1_1.CreatedContract]
    created_in_subview_archived_in_core: _containers.RepeatedScalarFieldContainer[str]
    resolved_keys: _containers.RepeatedCompositeFieldContainer[_participant_transaction_pb2_1.ResolvedKey]
    action_description: _participant_transaction_pb2_1_1_1.ActionDescription
    rollback_context: _participant_transaction_pb2.ViewParticipantData.RollbackContext
    def __init__(self, salt: _Optional[_Union[_crypto_pb2.Salt, _Mapping]] = ..., core_inputs: _Optional[_Iterable[_Union[_participant_transaction_pb2_1_1.InputContract, _Mapping]]] = ..., created_core: _Optional[_Iterable[_Union[_participant_transaction_pb2_1_1.CreatedContract, _Mapping]]] = ..., created_in_subview_archived_in_core: _Optional[_Iterable[str]] = ..., resolved_keys: _Optional[_Iterable[_Union[_participant_transaction_pb2_1.ResolvedKey, _Mapping]]] = ..., action_description: _Optional[_Union[_participant_transaction_pb2_1_1_1.ActionDescription, _Mapping]] = ..., rollback_context: _Optional[_Union[_participant_transaction_pb2.ViewParticipantData.RollbackContext, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/crypto/admin/v0/vault_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/crypto/admin/v0/vault_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ...v0 import crypto_pb2 as com_dot_digitalasset_dot_canton_dot_crypto_dot_v0_dot_crypto__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;com/digitalasset/canton/crypto/admin/v0/vault_service.proto\x12\'com.digitalasset.canton.crypto.admin.v0\x1a.com/digitalasset/canton/crypto/v0/crypto.proto\x1a\x1bgoogle/protobuf/empty.proto\"\xdd\x01\n\x1aGenerateCertificateRequest\x12+\n\x11unique_identifier\x18\x01 \x01(\tR\x10uniqueIdentifier\x12\'\n\x0f\x63\x65rtificate_key\x18\x02 \x01(\tR\x0e\x63\x65rtificateKey\x12-\n\x12\x61\x64\x64itional_subject\x18\x03 \x01(\tR\x11\x61\x64\x64itionalSubject\x12:\n\x19subject_alternative_names\x18\x04 \x03(\tR\x17subjectAlternativeNames\":\n\x1bGenerateCertificateResponse\x12\x1b\n\tx509_cert\x18\x01 \x01(\tR\x08x509Cert\"6\n\x16ListCertificateRequest\x12\x1c\n\tfilterUid\x18\x01 \x01(\tR\tfilterUid\"\xa3\x01\n\x17ListCertificateResponse\x12\x61\n\x07results\x18\x01 \x03(\x0b\x32G.com.digitalasset.canton.crypto.admin.v0.ListCertificateResponse.ResultR\x07results\x1a%\n\x06Result\x12\x1b\n\tx509_cert\x18\x01 \x01(\tR\x08x509Cert\"7\n\x18ImportCertificateRequest\x12\x1b\n\tx509_cert\x18\x01 \x01(\tR\x08x509Cert\"B\n\x19ImportCertificateResponse\x12%\n\x0e\x63\x65rtificate_id\x18\x01 \x01(\tR\rcertificateId\"K\n\x16ImportPublicKeyRequest\x12\x1d\n\npublic_key\x18\x01 \x01(\x0cR\tpublicKey\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\";\n\x17ImportPublicKeyResponse\x12 \n\x0b\x66ingerprint\x18\x01 \x01(\tR\x0b\x66ingerprint\"\xb7\x01\n\x0fListKeysRequest\x12-\n\x12\x66ilter_fingerprint\x18\x01 \x01(\tR\x11\x66ilterFingerprint\x12\x1f\n\x0b\x66ilter_name\x18\x02 \x01(\tR\nfilterName\x12T\n\x0e\x66ilter_purpose\x18\x03 \x03(\x0e\x32-.com.digitalasset.canton.crypto.v0.KeyPurposeR\rfilterPurpose\"\xa1\x01\n\x12PrivateKeyMetadata\x12\x65\n\x14public_key_with_name\x18\x01 \x01(\x0b\x32\x34.com.digitalasset.canton.crypto.v0.PublicKeyWithNameR\x11publicKeyWithName\x12$\n\x0ewrapper_key_id\x18\x02 \x01(\tR\x0cwrapperKeyId\"\x85\x01\n\x12ListMyKeysResponse\x12o\n\x15private_keys_metadata\x18\x01 \x03(\x0b\x32;.com.digitalasset.canton.crypto.admin.v0.PrivateKeyMetadataR\x13privateKeysMetadata\"i\n\x10ListKeysResponse\x12U\n\x0bpublic_keys\x18\x01 \x03(\x0b\x32\x34.com.digitalasset.canton.crypto.v0.PublicKeyWithNameR\npublicKeys\"\x83\x01\n\x19GenerateSigningKeyRequest\x12R\n\nkey_scheme\x18\x01 \x01(\x0e\x32\x33.com.digitalasset.canton.crypto.v0.SigningKeySchemeR\tkeyScheme\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\"p\n\x1aGenerateSigningKeyResponse\x12R\n\npublic_key\x18\x01 \x01(\x0b\x32\x33.com.digitalasset.canton.crypto.v0.SigningPublicKeyR\tpublicKey\"\x89\x01\n\x1cGenerateEncryptionKeyRequest\x12U\n\nkey_scheme\x18\x01 \x01(\x0e\x32\x36.com.digitalasset.canton.crypto.v0.EncryptionKeySchemeR\tkeyScheme\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\"v\n\x1dGenerateEncryptionKeyResponse\x12U\n\npublic_key\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.crypto.v0.EncryptionPublicKeyR\tpublicKey\"P\n\x1cRegisterKmsSigningKeyRequest\x12\x1c\n\nkms_key_id\x18\x01 \x01(\tR\x08kmsKeyId\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\"s\n\x1dRegisterKmsSigningKeyResponse\x12R\n\npublic_key\x18\x01 \x01(\x0b\x32\x33.com.digitalasset.canton.crypto.v0.SigningPublicKeyR\tpublicKey\"S\n\x1fRegisterKmsEncryptionKeyRequest\x12\x1c\n\nkms_key_id\x18\x01 \x01(\tR\x08kmsKeyId\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\"y\n RegisterKmsEncryptionKeyResponse\x12U\n\npublic_key\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.crypto.v0.EncryptionPublicKeyR\tpublicKey\"F\n\x17RotateWrapperKeyRequest\x12+\n\x12new_wrapper_key_id\x18\x01 \x01(\tR\x0fnewWrapperKeyId\"\x18\n\x16GetWrapperKeyIdRequest\"?\n\x17GetWrapperKeyIdResponse\x12$\n\x0ewrapper_key_id\x18\x01 \x01(\tR\x0cwrapperKeyId\"c\n\x14\x45xportKeyPairRequest\x12 \n\x0b\x66ingerprint\x18\x01 \x01(\tR\x0b\x66ingerprint\x12)\n\x10protocol_version\x18\x02 \x01(\x05R\x0fprotocolVersion\"2\n\x15\x45xportKeyPairResponse\x12\x19\n\x08key_pair\x18\x01 \x01(\x0cR\x07keyPair\"E\n\x14ImportKeyPairRequest\x12\x19\n\x08key_pair\x18\x01 \x01(\x0cR\x07keyPair\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\"\x17\n\x15ImportKeyPairResponse\"8\n\x14\x44\x65leteKeyPairRequest\x12 \n\x0b\x66ingerprint\x18\x01 \x01(\tR\x0b\x66ingerprint\"\x17\n\x15\x44\x65leteKeyPairResponse2\x8f\x0e\n\x0cVaultService\x12\x83\x01\n\nListMyKeys\x12\x38.com.digitalasset.canton.crypto.admin.v0.ListKeysRequest\x1a;.com.digitalasset.canton.crypto.admin.v0.ListMyKeysResponse\x12\x9d\x01\n\x12GenerateSigningKey\x12\x42.com.digitalasset.canton.crypto.admin.v0.GenerateSigningKeyRequest\x1a\x43.com.digitalasset.canton.crypto.admin.v0.GenerateSigningKeyResponse\x12\xa6\x01\n\x15GenerateEncryptionKey\x12\x45.com.digitalasset.canton.crypto.admin.v0.GenerateEncryptionKeyRequest\x1a\x46.com.digitalasset.canton.crypto.admin.v0.GenerateEncryptionKeyResponse\x12\xaf\x01\n\x18RegisterKmsEncryptionKey\x12H.com.digitalasset.canton.crypto.admin.v0.RegisterKmsEncryptionKeyRequest\x1aI.com.digitalasset.canton.crypto.admin.v0.RegisterKmsEncryptionKeyResponse\x12\xa6\x01\n\x15RegisterKmsSigningKey\x12\x45.com.digitalasset.canton.crypto.admin.v0.RegisterKmsSigningKeyRequest\x1a\x46.com.digitalasset.canton.crypto.admin.v0.RegisterKmsSigningKeyResponse\x12\x94\x01\n\x0fImportPublicKey\x12?.com.digitalasset.canton.crypto.admin.v0.ImportPublicKeyRequest\x1a@.com.digitalasset.canton.crypto.admin.v0.ImportPublicKeyResponse\x12\x85\x01\n\x0eListPublicKeys\x12\x38.com.digitalasset.canton.crypto.admin.v0.ListKeysRequest\x1a\x39.com.digitalasset.canton.crypto.admin.v0.ListKeysResponse\x12l\n\x10RotateWrapperKey\x12@.com.digitalasset.canton.crypto.admin.v0.RotateWrapperKeyRequest\x1a\x16.google.protobuf.Empty\x12\x94\x01\n\x0fGetWrapperKeyId\x12?.com.digitalasset.canton.crypto.admin.v0.GetWrapperKeyIdRequest\x1a@.com.digitalasset.canton.crypto.admin.v0.GetWrapperKeyIdResponse\x12\x8e\x01\n\rExportKeyPair\x12=.com.digitalasset.canton.crypto.admin.v0.ExportKeyPairRequest\x1a>.com.digitalasset.canton.crypto.admin.v0.ExportKeyPairResponse\x12\x8e\x01\n\rImportKeyPair\x12=.com.digitalasset.canton.crypto.admin.v0.ImportKeyPairRequest\x1a>.com.digitalasset.canton.crypto.admin.v0.ImportKeyPairResponse\x12\x8e\x01\n\rDeleteKeyPair\x12=.com.digitalasset.canton.crypto.admin.v0.DeleteKeyPairRequest\x1a>.com.digitalasset.canton.crypto.admin.v0.DeleteKeyPairResponseBXZVgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/crypto/admin/v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.crypto.admin.v0.vault_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZVgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/crypto/admin/v0'
  _globals['_GENERATECERTIFICATEREQUEST']._serialized_start=182
  _globals['_GENERATECERTIFICATEREQUEST']._serialized_end=403
  _globals['_GENERATECERTIFICATERESPONSE']._serialized_start=405
  _globals['_GENERATECERTIFICATERESPONSE']._serialized_end=463
  _globals['_LISTCERTIFICATEREQUEST']._serialized_start=465
  _globals['_LISTCERTIFICATEREQUEST']._serialized_end=519
  _globals['_LISTCERTIFICATERESPONSE']._serialized_start=522
  _globals['_LISTCERTIFICATERESPONSE']._serialized_end=685
  _globals['_LISTCERTIFICATERESPONSE_RESULT']._serialized_start=648
  _globals['_LISTCERTIFICATERESPONSE_RESULT']._serialized_end=685
  _globals['_IMPORTCERTIFICATEREQUEST']._serialized_start=687
  _globals['_IMPORTCERTIFICATEREQUEST']._serialized_end=742
  _globals['_IMPORTCERTIFICATERESPONSE']._serialized_start=744
  _globals['_IMPORTCERTIFICATERESPONSE']._serialized_end=810
  _globals['_IMPORTPUBLICKEYREQUEST']._serialized_start=812
  _globals['_IMPORTPUBLICKEYREQUEST']._serialized_end=887
  _globals['_IMPORTPUBLICKEYRESPONSE']._serialized_start=889
  _globals['_IMPORTPUBLICKEYRESPONSE']._serialized_end=948
  _globals['_LISTKEYSREQUEST']._serialized_start=951
  _globals['_LISTKEYSREQUEST']._serialized_end=1134
  _globals['_PRIVATEKEYMETADATA']._serialized_start=1137
  _globals['_PRIVATEKEYMETADATA']._serialized_end=1298
  _globals['_LISTMYKEYSRESPONSE']._serialized_start=1301
  _globals['_LISTMYKEYSRESPONSE']._serialized_end=1434
  _globals['_LISTKEYSRESPONSE']._serialized_start=1436
  _globals['_LISTKEYSRESPONSE']._serialized_end=1541
  _globals['_GENERATESIGNINGKEYREQUEST']._serialized_start=1544
  _globals['_GENERATESIGNINGKEYREQUEST']._serialized_end=1675
  _globals['_GENERATESIGNINGKEYRESPONSE']._serialized_start=1677
  _globals['_GENERATESIGNINGKEYRESPONSE']._serialized_end=1789
  _globals['_GENERATEENCRYPTIONKEYREQUEST']._serialized_start=1792
  _globals['_GENERATEENCRYPTIONKEYREQUEST']._serialized_end=1929
  _globals['_GENERATEENCRYPTIONKEYRESPONSE']._serialized_start=1931
  _globals['_GENERATEENCRYPTIONKEYRESPONSE']._serialized_end=2049
  _globals['_REGISTERKMSSIGNINGKEYREQUEST']._serialized_start=2051
  _globals['_REGISTERKMSSIGNINGKEYREQUEST']._serialized_end=2131
  _globals['_REGISTERKMSSIGNINGKEYRESPONSE']._serialized_start=2133
  _globals['_REGISTERKMSSIGNINGKEYRESPONSE']._serialized_end=2248
  _globals['_REGISTERKMSENCRYPTIONKEYREQUEST']._serialized_start=2250
  _globals['_REGISTERKMSENCRYPTIONKEYREQUEST']._serialized_end=2333
  _globals['_REGISTERKMSENCRYPTIONKEYRESPONSE']._serialized_start=2335
  _globals['_REGISTERKMSENCRYPTIONKEYRESPONSE']._serialized_end=2456
  _globals['_ROTATEWRAPPERKEYREQUEST']._serialized_start=2458
  _globals['_ROTATEWRAPPERKEYREQUEST']._serialized_end=2528
  _globals['_GETWRAPPERKEYIDREQUEST']._serialized_start=2530
  _globals['_GETWRAPPERKEYIDREQUEST']._serialized_end=2554
  _globals['_GETWRAPPERKEYIDRESPONSE']._serialized_start=2556
  _globals['_GETWRAPPERKEYIDRESPONSE']._serialized_end=2619
  _globals['_EXPORTKEYPAIRREQUEST']._serialized_start=2621
  _globals['_EXPORTKEYPAIRREQUEST']._serialized_end=2720
  _globals['_EXPORTKEYPAIRRESPONSE']._serialized_start=2722
  _globals['_EXPORTKEYPAIRRESPONSE']._serialized_end=2772
  _globals['_IMPORTKEYPAIRREQUEST']._serialized_start=2774
  _globals['_IMPORTKEYPAIRREQUEST']._serialized_end=2843
  _globals['_IMPORTKEYPAIRRESPONSE']._serialized_start=2845
  _globals['_IMPORTKEYPAIRRESPONSE']._serialized_end=2868
  _globals['_DELETEKEYPAIRREQUEST']._serialized_start=2870
  _globals['_DELETEKEYPAIRREQUEST']._serialized_end=2926
  _globals['_DELETEKEYPAIRRESPONSE']._serialized_start=2928
  _globals['_DELETEKEYPAIRRESPONSE']._serialized_end=2951
  _globals['_VAULTSERVICE']._serialized_start=2954
  _globals['_VAULTSERVICE']._serialized_end=4761
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from . import value_pb2 as _value_pb2
from google.protobuf import wrappers_pb2 as _wrappers_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.rpc import status_pb2 as _status_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Event(_message.Message):
    __slots__ = ("created", "archived")
    CREATED_FIELD_NUMBER: _ClassVar[int]
    ARCHIVED_FIELD_NUMBER: _ClassVar[int]
    created: CreatedEvent
    archived: ArchivedEvent
    def __init__(self, created: _Optional[_Union[CreatedEvent, _Mapping]] = ..., archived: _Optional[_Union[ArchivedEvent, _Mapping]] = ...) -> None: ...

class CreatedEvent(_message.Message):
    __slots__ = ("event_id", "contract_id", "template_id", "package_name", "contract_key", "create_arguments", "created_event_blob", "interface_views", "witness_parties", "signatories", "observers", "agreement_text", "created_at")
    EVENT_ID_FIELD_NUMBER: _ClassVar[int]
    CONTRACT_ID_FIELD_NUMBER: _ClassVar[int]
    TEMPLATE_ID_FIELD_NUMBER: _ClassVar[int]
    PACKAGE_NAME_FIELD_NUMBER: _ClassVar[int]
    CONTRACT_KEY_FIELD_NUMBER: _ClassVar[int]
    CREATE_ARGUMENTS_FIELD_NUMBER: _ClassVar[int]
    CREATED_EVENT_BLOB_FIELD_NUMBER: _ClassVar[int]
    INTERFACE_VIEWS_FIELD_NUMBER: _ClassVar[int]
    WITNESS_PARTIES_FIELD_NUMBER: _ClassVar[int]
    SIGNATORIES_FIELD_NUMBER: _ClassVar[int]
    OBSERVERS_FIELD_NUMBER: _ClassVar[int]
    AGREEMENT_TEXT_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    event_id: str
    contract_id: str
    template_id: _value_pb2.Identifier
    package_name: _wrappers_pb2.StringValue
    contract_key: _value_pb2.Value
    create_arguments: _value_pb2.Record
    created_event_blob: bytes
    interface_views: _containers.RepeatedCompositeFieldContainer[InterfaceView]
    witness_parties: _containers.RepeatedScalarFieldContainer[str]
    signatories: _containers.RepeatedScalarFieldContainer[str]
    observers: _containers.RepeatedScalarFieldContainer[str]
    agreement_text: _wrappers_pb2.StringValue
    created_at: _timestamp_pb2.Timestamp
    def __init__(self, event_id: _Optional[str] = ..., contract_id: _Optional[str] = ..., template_id: _Optional[_Union[_value_pb2.Identifier, _Mapping]] = ..., package_name: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., contract_key: _Optional[_Union[_value_pb2.Value, _Mapping]] = ..., create_arguments: _Optional[_Union[_value_pb2.Record, _Mapping]] = ..., created_event_blob: _Optional[bytes] = ..., interface_views: _Optional[_Iterable[_Union[InterfaceView, _Mapping]]] = ..., witness_parties: _Optional[_Iterable[str]] = ..., signatories: _Optional[_Iterable[str]] = ..., observers: _Optional[_Iterable[str]] = ..., agreement_text: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class InterfaceView(_message.Message):
    __slots__ = ("interface_id", "view_status", "view_value")
    INTERFACE_ID_FIELD_NUMBER: _ClassVar[int]
    VIEW_STATUS_FIELD_NUMBER: _ClassVar[int]
    VIEW_VALUE_FIELD_NUMBER: _ClassVar[int]
    interface_id: _value_pb2.Identifier
    view_status: _status_pb2.Status
    view_value: _value_pb2.Record
    def __init__(self, interface_id: _Optional[_Union[_value_pb2.Identifier, _Mapping]] = ..., view_status: _Optional[_Union[_status_pb2.Status, _Mapping]] = ..., view_value: _Optional[_Union[_value_pb2.Record, _Mapping]] = ...) -> None: ...

class ArchivedEvent(_message.Message):
    __slots__ = ("event_id", "contract_id", "template_id", "witness_parties")
    EVENT_ID_FIELD_NUMBER: _ClassVar[int]
    CONTRACT_ID_FIELD_NUMBER: _ClassVar[int]
    TEMPLATE_ID_FIELD_NUMBER: _ClassVar[int]
    WITNESS_PARTIES_FIELD_NUMBER: _ClassVar[int]
    event_id: str
    contract_id: str
    template_id: _value_pb2.Identifier
    witness_parties: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, event_id: _Optional[str] = ..., contract_id: _Optional[str] = ..., template_id: _Optional[_Union[_value_pb2.Identifier, _Mapping]] = ..., witness_parties: _Optional[_Iterable[str]] = ...) -> None: ...

class ExercisedEvent(_message.Message):
    __slots__ = ("event_id", "contract_id", "template_id", "package_name", "interface_id", "choice", "choice_argument", "acting_parties", "consuming", "witness_parties", "child_event_ids", "exercise_result")
    EVENT_ID_FIELD_NUMBER: _ClassVar[int]
    CONTRACT_ID_FIELD_NUMBER: _ClassVar[int]
    TEMPLATE_ID_FIELD_NUMBER: _ClassVar[int]
    PACKAGE_NAME_FIELD_NUMBER: _ClassVar[int]
    INTERFACE_ID_FIELD_NUMBER: _ClassVar[int]
    CHOICE_FIELD_NUMBER: _ClassVar[int]
    CHOICE_ARGUMENT_FIELD_NUMBER: _ClassVar[int]
    ACTING_PARTIES_FIELD_NUMBER: _ClassVar[int]
    CONSUMING_FIELD_NUMBER: _ClassVar[int]
    WITNESS_PARTIES_FIELD_NUMBER: _ClassVar[int]
    CHILD_EVENT_IDS_FIELD_NUMBER: _ClassVar[int]
    EXERCISE_RESULT_FIELD_NUMBER: _ClassVar[int]
    event_id: str
    contract_id: str
    template_id: _value_pb2.Identifier
    package_name: _wrappers_pb2.StringValue
    interface_id: _value_pb2.Identifier
    choice: str
    choice_argument: _value_pb2.Value
    acting_parties: _containers.RepeatedScalarFieldContainer[str]
    consuming: bool
    witness_parties: _containers.RepeatedScalarFieldContainer[str]
    child_event_ids: _containers.RepeatedScalarFieldContainer[str]
    exercise_result: _value_pb2.Value
    def __init__(self, event_id: _Optional[str] = ..., contract_id: _Optional[str] = ..., template_id: _Optional[_Union[_value_pb2.Identifier, _Mapping]] = ..., package_name: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., interface_id: _Optional[_Union[_value_pb2.Identifier, _Mapping]] = ..., choice: _Optional[str] = ..., choice_argument: _Optional[_Union[_value_pb2.Value, _Mapping]] = ..., acting_parties: _Optional[_Iterable[str]] = ..., consuming: bool = ..., witness_parties: _Optional[_Iterable[str]] = ..., child_event_ids: _Optional[_Iterable[str]] = ..., exercise_result: _Optional[_Union[_value_pb2.Value, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/daml/ledger/api/v2/admin/party_management_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/daml/ledger/api/v2/admin/party_management_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import object_meta_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_admin_dot_object__meta__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;com/daml/ledger/api/v2/admin/party_management_service.proto\x12\x1c\x63om.daml.ledger.api.v2.admin\x1a.com/daml/ledger/api/v2/admin/object_meta.proto\x1a google/protobuf/field_mask.proto\"\x19\n\x17GetParticipantIdRequest\"A\n\x18GetParticipantIdResponse\x12%\n\x0eparticipant_id\x18\x01 \x01(\tR\rparticipantId\"_\n\x11GetPartiesRequest\x12\x18\n\x07parties\x18\x01 \x03(\tR\x07parties\x12\x30\n\x14identity_provider_id\x18\x02 \x01(\tR\x12identityProviderId\"e\n\x12GetPartiesResponse\x12O\n\rparty_details\x18\x01 \x03(\x0b\x32*.com.daml.ledger.api.v2.admin.PartyDetailsR\x0cpartyDetails\"\x87\x01\n\x17ListKnownPartiesRequest\x12\x1d\n\npage_token\x18\x02 \x01(\tR\tpageToken\x12\x1b\n\tpage_size\x18\x03 \x01(\x05R\x08pageSize\x12\x30\n\x14identity_provider_id\x18\x01 \x01(\tR\x12identityProviderId\"\x93\x01\n\x18ListKnownPartiesResponse\x12O\n\rparty_details\x18\x01 \x03(\x0b\x32*.com.daml.ledger.api.v2.admin.PartyDetailsR\x0cpartyDetails\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"\xe0\x01\n\x14\x41llocatePartyRequest\x12\"\n\rparty_id_hint\x18\x01 \x01(\tR\x0bpartyIdHint\x12!\n\x0c\x64isplay_name\x18\x02 \x01(\tR\x0b\x64isplayName\x12O\n\x0elocal_metadata\x18\x03 \x01(\x0b\x32(.com.daml.ledger.api.v2.admin.ObjectMetaR\rlocalMetadata\x12\x30\n\x14identity_provider_id\x18\x04 \x01(\tR\x12identityProviderId\"h\n\x15\x41llocatePartyResponse\x12O\n\rparty_details\x18\x01 \x01(\x0b\x32*.com.daml.ledger.api.v2.admin.PartyDetailsR\x0cpartyDetails\"\xa9\x01\n\x19UpdatePartyDetailsRequest\x12O\n\rparty_details\x18\x01 \x01(\x0b\x32*.com.daml.ledger.api.v2.admin.PartyDetailsR\x0cpartyDetails\x12;\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskR\nupdateMask\"m\n\x1aUpdatePartyDetailsResponse\x12O\n\rparty_details\x18\x01 \x01(\x0b\x32*.com.daml.ledger.api.v2.admin.PartyDetailsR\x0cpartyDetails\"\xe5\x01\n\x0cPartyDetails\x12\x14\n\x05party\x18\x01 \x01(\tR\x05party\x12!\n\x0c\x64isplay_name\x18\x02 \x01(\tR\x0b\x64isplayName\x12\x19\n\x08is_local\x18\x03 \x01(\x08R\x07isLocal\x12O\n\x0elocal_metadata\x18\x04 \x01(\x0b\x32(.com.daml.ledger.api.v2.admin.ObjectMetaR\rlocalMetadata\x12\x30\n\x14identity_provider_id\x18\x05 \x01(\tR\x12identityProviderId\"\xba\x01\n$UpdatePartyIdentityProviderIdRequest\x12\x14\n\x05party\x18\x01 \x01(\tR\x05party\x12=\n\x1bsource_identity_provider_id\x18\x02 \x01(\tR\x18sourceIdentityProviderId\x12=\n\x1btarget_identity_provider_id\x18\x03 \x01(\tR\x18targetIdentityProviderId\"\'\n%UpdatePartyIdentityProviderIdResponse2\xc0\x06\n\x16PartyManagementService\x12\x81\x01\n\x10GetParticipantId\x12\x35.com.daml.ledger.api.v2.admin.GetParticipantIdRequest\x1a\x36.com.daml.ledger.api.v2.admin.GetParticipantIdResponse\x12o\n\nGetParties\x12/.com.daml.ledger.api.v2.admin.GetPartiesRequest\x1a\x30.com.daml.ledger.api.v2.admin.GetPartiesResponse\x12\x81\x01\n\x10ListKnownParties\x12\x35.com.daml.ledger.api.v2.admin.ListKnownPartiesRequest\x1a\x36.com.daml.ledger.api.v2.admin.ListKnownPartiesResponse\x12x\n\rAllocateParty\x12\x32.com.daml.ledger.api.v2.admin.AllocatePartyRequest\x1a\x33.com.daml.ledger.api.v2.admin.AllocatePartyResponse\x12\x87\x01\n\x12UpdatePartyDetails\x12\x37.com.daml.ledger.api.v2.admin.UpdatePartyDetailsRequest\x1a\x38.com.daml.ledger.api.v2.admin.UpdatePartyDetailsResponse\x12\xa8\x01\n\x1dUpdatePartyIdentityProviderId\x12\x42.com.daml.ledger.api.v2.admin.UpdatePartyIdentityProviderIdRequest\x1a\x43.com.daml.ledger.api.v2.admin.UpdatePartyIdentityProviderIdResponseB\xac\x01\n\x1c\x63om.daml.ledger.api.v2.adminB PartyManagementServiceOuterClassZKgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2/admin\xaa\x02\x1c\x43om.Daml.Ledger.Api.V2.Adminb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.daml.ledger.api.v2.admin.party_management_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034com.daml.ledger.api.v2.adminB PartyManagementServiceOuterClassZKgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2/admin\252\002\034Com.Daml.Ledger.Api.V2.Admin'
  _globals['_GETPARTICIPANTIDREQUEST']._serialized_start=175
  _globals['_GETPARTICIPANTIDREQUEST']._serialized_end=200
  _globals['_GETPARTICIPANTIDRESPONSE']._serialized_start=202
  _globals['_GETPARTICIPANTIDRESPONSE']._serialized_end=267
  _globals['_GETPARTIESREQUEST']._serialized_start=269
  _globals['_GETPARTIESREQUEST']._serialized_end=364
  _globals['_GETPARTIESRESPONSE']._serialized_start=366
  _globals['_GETPARTIESRESPONSE']._serialized_end=467
  _globals['_LISTKNOWNPARTIESREQUEST']._serialized_start=470
  _globals['_LISTKNOWNPARTIESREQUEST']._serialized_end=605
  _globals['_LISTKNOWNPARTIESRESPONSE']._serialized_start=608
  _globals['_LISTKNOWNPARTIESRESPONSE']._serialized_end=755
  _globals['_ALLOCATEPARTYREQUEST']._serialized_start=758
  _globals['_ALLOCATEPARTYREQUEST']._serialized_end=982
  _globals['_ALLOCATEPARTYRESPONSE']._serialized_start=984
  _globals['_ALLOCATEPARTYRESPONSE']._serialized_end=1088
  _globals['_UPDATEPARTYDETAILSREQUEST']._serialized_start=1091
  _globals['_UPDATEPARTYDETAILSREQUEST']._serialized_end=1260
  _globals['_UPDATEPARTYDETAILSRESPONSE']._serialized_start=1262
  _globals['_UPDATEPARTYDETAILSRESPONSE']._serialized_end=1371
  _globals['_PARTYDETAILS']._serialized_start=1374
  _globals['_PARTYDETAILS']._serialized_end=1603
  _globals['_UPDATEPARTYIDENTITYPROVIDERIDREQUEST']._serialized_start=1606
  _globals['_UPDATEPARTYIDENTITYPROVIDERIDREQUEST']._serialized_end=1792
  _globals['_UPDATEPARTYIDENTITYPROVIDERIDRESPONSE']._serialized_start=1794
  _globals['_UPDATEPARTYIDENTITYPROVIDERIDRESPONSE']._serialized_end=1833
  _globals['_PARTYMANAGEMENTSERVICE']._serialized_start=1836
  _globals['_PARTYMANAGEMENTSERVICE']._serialized_end=2668
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from ....crypto.v0 import crypto_pb2 as _crypto_pb2
from . import sequencer_initialization_snapshot_pb2 as _sequencer_initialization_snapshot_pb2
from ..v1 import sequencer_initialization_service_pb2 as _sequencer_initialization_service_pb2
from ....protocol.v0 import sequencing_pb2 as _sequencing_pb2
from ....protocol.v0 import topology_ext_pb2 as _topology_ext_pb2
from google.protobuf import empty_pb2 as _empty_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class InitRequest(_message.Message):
    __slots__ = ("domain_id", "topology_snapshot", "domain_parameters", "snapshot")
    DOMAIN_ID_FIELD_NUMBER: _ClassVar[int]
    TOPOLOGY_SNAPSHOT_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_PARAMETERS_FIELD_NUMBER: _ClassVar[int]
    SNAPSHOT_FIELD_NUMBER: _ClassVar[int]
    domain_id: str
    topology_snapshot: _topology_ext_pb2.TopologyTransactions
    domain_parameters: _sequencing_pb2.StaticDomainParameters
    snapshot: _sequencer_initialization_snapshot_pb2.SequencerSnapshot
    def __init__(self, domain_id: _Optional[str] = ..., topology_snapshot: _Optional[_Union[_topology_ext_pb2.TopologyTransactions, _Mapping]] = ..., domain_parameters: _Optional[_Union[_sequencing_pb2.StaticDomainParameters, _Mapping]] = ..., snapshot: _Optional[_Union[_sequencer_initialization_snapshot_pb2.SequencerSnapshot, _Mapping]] = ...) -> None: ...

class InitResponse(_message.Message):
    __slots__ = ("key_id", "public_key", "replicated")
    KEY_ID_FIELD_NUMBER: _ClassVar[int]
    PUBLIC_KEY_FIELD_NUMBER: _ClassVar[int]
    REPLICATED_FIELD_NUMBER: _ClassVar[int]
    key_id: str
    public_key: _crypto_pb2.SigningPublicKey
    replicated: bool
    def __init__(self, key_id: _Optional[str] = ..., public_key: _Optional[_Union[_crypto_pb2.SigningPublicKey, _Mapping]] = ..., replicated: bool = ...) -> None: ...

class TopologyBootstrapRequest(_message.Message):
    __slots__ = ("initial_topology_snapshot",)
    INITIAL_TOPOLOGY_SNAPSHOT_FIELD_NUMBER: _ClassVar[int]
    initial_topology_snapshot: _topology_ext_pb2.TopologyTransactions
    def __init__(self, initial_topology_snapshot: _Optional[_Union[_topology_ext_pb2.TopologyTransactions, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

import builtins as _builtins, typing as _typing

import grpc as _grpc
from grpc import aio as _grpc_aio

from .sequencer_connect_service_pb2 import SequencerConnect

__all__ = [
    "SequencerConnectServiceStub",
]


# noinspection PyPep8Naming,DuplicatedCode
class SequencerConnectServiceStub:
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc.Channel) -> _SequencerConnectServiceBlockingStub: ...  # type: ignore
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc_aio.Channel) -> _SequencerConnectServiceAsyncStub: ...  # type: ignore
    def Handshake(self, __1: SequencerConnect.HandshakeRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[SequencerConnect.HandshakeResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, SequencerConnect.HandshakeResponse]]: ...
    def GetDomainId(self, __1: SequencerConnect.GetDomainIdRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[SequencerConnect.GetDomainIdResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, SequencerConnect.GetDomainIdResponse]]: ...
    def GetDomainParameters(self, __1: SequencerConnect.GetDomainParametersRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[SequencerConnect.GetDomainParametersResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, SequencerConnect.GetDomainParametersResponse]]: ...
    def VerifyActive(self, __1: SequencerConnect.VerifyActiveRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[SequencerConnect.VerifyActiveResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, SequencerConnect.VerifyActiveResponse]]: ...
    def RegisterOnboardingTopologyTransactions(self, __1: SequencerConnect.RegisterOnboardingTopologyTransactionsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[SequencerConnect.RegisterOnboardingTopologyTransactionsResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, SequencerConnect.RegisterOnboardingTopologyTransactionsResponse]]: ...

# noinspection PyPep8Naming,DuplicatedCode
class _SequencerConnectServiceBlockingStub(SequencerConnectServiceStub):
    def Handshake(self, __1: SequencerConnect.HandshakeRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> SequencerConnect.HandshakeResponse: ...
    def GetDomainId(self, __1: SequencerConnect.GetDomainIdRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> SequencerConnect.GetDomainIdResponse: ...
    def GetDomainParameters(self, __1: SequencerConnect.GetDomainParametersRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> SequencerConnect.GetDomainParametersResponse: ...
    def VerifyActive(self, __1: SequencerConnect.VerifyActiveRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> SequencerConnect.VerifyActiveResponse: ...
    def RegisterOnboardingTopologyTransactions(self, __1: SequencerConnect.RegisterOnboardingTopologyTransactionsRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> SequencerConnect.RegisterOnboardingTopologyTransactionsResponse: ...

# noinspection PyPep8Naming,DuplicatedCode
class _SequencerConnectServiceAsyncStub(SequencerConnectServiceStub):
    def Handshake(self, __1: SequencerConnect.HandshakeRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, SequencerConnect.HandshakeResponse]: ...  # type: ignore
    def GetDomainId(self, __1: SequencerConnect.GetDomainIdRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, SequencerConnect.GetDomainIdResponse]: ...  # type: ignore
    def GetDomainParameters(self, __1: SequencerConnect.GetDomainParametersRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, SequencerConnect.GetDomainParametersResponse]: ...  # type: ignore
    def VerifyActive(self, __1: SequencerConnect.VerifyActiveRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, SequencerConnect.VerifyActiveResponse]: ...  # type: ignore
    def RegisterOnboardingTopologyTransactions(self, __1: SequencerConnect.RegisterOnboardingTopologyTransactionsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, SequencerConnect.RegisterOnboardingTopologyTransactionsResponse]: ...  # type: ignore



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/admin/pruning/v30/pruning.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/admin/pruning/v30/pruning.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7com/digitalasset/canton/admin/pruning/v30/pruning.proto\x12)com.digitalasset.canton.admin.pruning.v30\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"|\n\x0bSetSchedule\x1a\x61\n\x07Request\x12V\n\x08schedule\x18\x01 \x01(\x0b\x32:.com.digitalasset.canton.admin.pruning.v30.PruningScheduleR\x08schedule\x1a\n\n\x08Response\"|\n\x0bGetSchedule\x1a\t\n\x07Request\x1a\x62\n\x08Response\x12V\n\x08schedule\x18\x01 \x01(\x0b\x32:.com.digitalasset.canton.admin.pruning.v30.PruningScheduleR\x08schedule\"\x92\x01\n\x16SetParticipantSchedule\x1al\n\x07Request\x12\x61\n\x08schedule\x18\x01 \x01(\x0b\x32\x45.com.digitalasset.canton.admin.pruning.v30.ParticipantPruningScheduleR\x08schedule\x1a\n\n\x08Response\"\x92\x01\n\x16GetParticipantSchedule\x1a\t\n\x07Request\x1am\n\x08Response\x12\x61\n\x08schedule\x18\x01 \x01(\x0b\x32\x45.com.digitalasset.canton.admin.pruning.v30.ParticipantPruningScheduleR\x08schedule\"\x9c\x01\n\x0fPruningSchedule\x12\x12\n\x04\x63ron\x18\x01 \x01(\tR\x04\x63ron\x12<\n\x0cmax_duration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationR\x0bmaxDuration\x12\x37\n\tretention\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationR\tretention\"\xa8\x01\n\x1aParticipantPruningSchedule\x12V\n\x08schedule\x18\x01 \x01(\x0b\x32:.com.digitalasset.canton.admin.pruning.v30.PruningScheduleR\x08schedule\x12\x32\n\x15prune_internally_only\x18\x02 \x01(\x08R\x13pruneInternallyOnly\"&\n\rClearSchedule\x1a\t\n\x07Request\x1a\n\n\x08Response\"4\n\x07SetCron\x1a\x1d\n\x07Request\x12\x12\n\x04\x63ron\x18\x01 \x01(\tR\x04\x63ron\x1a\n\n\x08Response\"e\n\x0eSetMaxDuration\x1aG\n\x07Request\x12<\n\x0cmax_duration\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationR\x0bmaxDuration\x1a\n\n\x08Response\"^\n\x0cSetRetention\x1a\x42\n\x07Request\x12\x37\n\tretention\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationR\tretention\x1a\n\n\x08Response\"\x7f\n\x16LocatePruningTimestamp\x1a\x1f\n\x07Request\x12\x14\n\x05index\x18\x01 \x01(\x05R\x05index\x1a\x44\n\x08Response\x12\x38\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\"\xce\x04\n\x18SetNoWaitCommitmentsFrom\x1a\xf3\x01\n\x07Request\x12\x38\n\x18\x63ounter_participant_uids\x18\x01 \x03(\tR\x16\x63ounterParticipantUids\x12O\n\x14sequencing_timestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00R\x13sequencingTimestamp\x12\'\n\x0epruning_offset\x18\x04 \x01(\tH\x00R\rpruningOffset\x12\x1d\n\ndomain_ids\x18\x05 \x03(\tR\tdomainIdsB\x15\n\x13timestamp_or_offset\x1a\xbb\x02\n\x08Response\x12\xab\x01\n\x1bparticipant_domains_mapping\x18\x01 \x03(\x0b\x32k.com.digitalasset.canton.admin.pruning.v30.SetNoWaitCommitmentsFrom.Response.ParticipantDomainsMappingEntryR\x19participantDomainsMapping\x1a\x80\x01\n\x1eParticipantDomainsMappingEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12H\n\x05value\x18\x02 \x01(\x0b\x32\x32.com.digitalasset.canton.admin.pruning.v30.DomainsR\x05value:\x02\x38\x01\"\xc0\x03\n\x1aResetNoWaitCommitmentsFrom\x1a\x62\n\x07Request\x12\x38\n\x18\x63ounter_participant_uids\x18\x01 \x03(\tR\x16\x63ounterParticipantUids\x12\x1d\n\ndomain_ids\x18\x02 \x03(\tR\tdomainIds\x1a\xbd\x02\n\x08Response\x12\xad\x01\n\x1bparticipant_domains_mapping\x18\x01 \x03(\x0b\x32m.com.digitalasset.canton.admin.pruning.v30.ResetNoWaitCommitmentsFrom.Response.ParticipantDomainsMappingEntryR\x19participantDomainsMapping\x1a\x80\x01\n\x1eParticipantDomainsMappingEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12H\n\x05value\x18\x02 \x01(\x0b\x32\x32.com.digitalasset.canton.admin.pruning.v30.DomainsR\x05value:\x02\x38\x01\"(\n\x07\x44omains\x12\x1d\n\ndomain_ids\x18\x01 \x03(\tR\tdomainIds\"\xed\x02\n\x18GetNoWaitCommitmentsFrom\x1aS\n\x07Request\x12\x1d\n\ndomain_ids\x18\x01 \x03(\tR\tdomainIds\x12)\n\x10participant_uids\x18\x02 \x03(\tR\x0fparticipantUids\x1a\xfb\x01\n\x08Response\x12t\n\x14ignored_participants\x18\x01 \x03(\x0b\x32\x41.com.digitalasset.canton.admin.pruning.v30.NoWaitCommitmentsSetupR\x13ignoredParticipants\x12y\n\x18not_ignored_participants\x18\x02 \x03(\x0b\x32?.com.digitalasset.canton.admin.pruning.v30.WaitCommitmentsSetupR\x16notIgnoredParticipants\"\xb8\x03\n\x16NoWaitCommitmentsSetup\x12\x36\n\x17\x63ounter_participant_uid\x18\x01 \x01(\tR\x15\x63ounterParticipantUid\x12O\n\x14sequencing_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00R\x13sequencingTimestamp\x12\'\n\x0epruning_offset\x18\x03 \x01(\tH\x00R\rpruningOffset\x12Q\n\ndomain_ids\x18\x04 \x01(\x0b\x32\x32.com.digitalasset.canton.admin.pruning.v30.DomainsR\tdomainIds\x12{\n\x19\x63ounter_participant_state\x18\x05 \x01(\x0e\x32?.com.digitalasset.canton.admin.pruning.v30.SharedContractsStateR\x17\x63ounterParticipantStateB\x1c\n\x1atimestamp_or_offset_active\"\x9e\x02\n\x14WaitCommitmentsSetup\x12\x36\n\x17\x63ounter_participant_uid\x18\x01 \x01(\tR\x15\x63ounterParticipantUid\x12Q\n\ndomain_ids\x18\x02 \x01(\x0b\x32\x32.com.digitalasset.canton.admin.pruning.v30.DomainsR\tdomainIds\x12{\n\x19\x63ounter_participant_state\x18\x03 \x01(\x0e\x32?.com.digitalasset.canton.admin.pruning.v30.SharedContractsStateR\x17\x63ounterParticipantState*\\\n\x14SharedContractsState\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x14\n\x10SHARED_CONTRACTS\x10\x01\x12\x17\n\x13NO_SHARED_CONTRACTS\x10\x02\x42ZZXgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/pruning/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.admin.pruning.v30.pruning_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZXgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/pruning/v30'
  _globals['_SETNOWAITCOMMITMENTSFROM_RESPONSE_PARTICIPANTDOMAINSMAPPINGENTRY']._loaded_options = None
  _globals['_SETNOWAITCOMMITMENTSFROM_RESPONSE_PARTICIPANTDOMAINSMAPPINGENTRY']._serialized_options = b'8\001'
  _globals['_RESETNOWAITCOMMITMENTSFROM_RESPONSE_PARTICIPANTDOMAINSMAPPINGENTRY']._loaded_options = None
  _globals['_RESETNOWAITCOMMITMENTSFROM_RESPONSE_PARTICIPANTDOMAINSMAPPINGENTRY']._serialized_options = b'8\001'
  _globals['_SHAREDCONTRACTSSTATE']._serialized_start=3655
  _globals['_SHAREDCONTRACTSSTATE']._serialized_end=3747
  _globals['_SETSCHEDULE']._serialized_start=167
  _globals['_SETSCHEDULE']._serialized_end=291
  _globals['_SETSCHEDULE_REQUEST']._serialized_start=182
  _globals['_SETSCHEDULE_REQUEST']._serialized_end=279
  _globals['_SETSCHEDULE_RESPONSE']._serialized_start=281
  _globals['_SETSCHEDULE_RESPONSE']._serialized_end=291
  _globals['_GETSCHEDULE']._serialized_start=293
  _globals['_GETSCHEDULE']._serialized_end=417
  _globals['_GETSCHEDULE_REQUEST']._serialized_start=182
  _globals['_GETSCHEDULE_REQUEST']._serialized_end=191
  _globals['_GETSCHEDULE_RESPONSE']._serialized_start=319
  _globals['_GETSCHEDULE_RESPONSE']._serialized_end=417
  _globals['_SETPARTICIPANTSCHEDULE']._serialized_start=420
  _globals['_SETPARTICIPANTSCHEDULE']._serialized_end=566
  _globals['_SETPARTICIPANTSCHEDULE_REQUEST']._serialized_start=446
  _globals['_SETPARTICIPANTSCHEDULE_REQUEST']._serialized_end=554
  _globals['_SETPARTICIPANTSCHEDULE_RESPONSE']._serialized_start=281
  _globals['_SETPARTICIPANTSCHEDULE_RESPONSE']._serialized_end=291
  _globals['_GETPARTICIPANTSCHEDULE']._serialized_start=569
  _globals['_GETPARTICIPANTSCHEDULE']._serialized_end=715
  _globals['_GETPARTICIPANTSCHEDULE_REQUEST']._serialized_start=182
  _globals['_GETPARTICIPANTSCHEDULE_REQUEST']._serialized_end=191
  _globals['_GETPARTICIPANTSCHEDULE_RESPONSE']._serialized_start=606
  _globals['_GETPARTICIPANTSCHEDULE_RESPONSE']._serialized_end=715
  _globals['_PRUNINGSCHEDULE']._serialized_start=718
  _globals['_PRUNINGSCHEDULE']._serialized_end=874
  _globals['_PARTICIPANTPRUNINGSCHEDULE']._serialized_start=877
  _globals['_PARTICIPANTPRUNINGSCHEDULE']._serialized_end=1045
  _globals['_CLEARSCHEDULE']._serialized_start=1047
  _globals['_CLEARSCHEDULE']._serialized_end=1085
  _globals['_CLEARSCHEDULE_REQUEST']._serialized_start=182
  _globals['_CLEARSCHEDULE_REQUEST']._serialized_end=191
  _globals['_CLEARSCHEDULE_RESPONSE']._serialized_start=281
  _globals['_CLEARSCHEDULE_RESPONSE']._serialized_end=291
  _globals['_SETCRON']._serialized_start=1087
  _globals['_SETCRON']._serialized_end=1139
  _globals['_SETCRON_REQUEST']._serialized_start=1098
  _globals['_SETCRON_REQUEST']._serialized_end=1127
  _globals['_SETCRON_RESPONSE']._serialized_start=281
  _globals['_SETCRON_RESPONSE']._serialized_end=291
  _globals['_SETMAXDURATION']._serialized_start=1141
  _globals['_SETMAXDURATION']._serialized_end=1242
  _globals['_SETMAXDURATION_REQUEST']._serialized_start=1159
  _globals['_SETMAXDURATION_REQUEST']._serialized_end=1230
  _globals['_SETMAXDURATION_RESPONSE']._serialized_start=281
  _globals['_SETMAXDURATION_RESPONSE']._serialized_end=291
  _globals['_SETRETENTION']._serialized_start=1244
  _globals['_SETRETENTION']._serialized_end=1338
  _globals['_SETRETENTION_REQUEST']._serialized_start=1260
  _globals['_SETRETENTION_REQUEST']._serialized_end=1326
  _globals['_SETRETENTION_RESPONSE']._serialized_start=281
  _globals['_SETRETENTION_RESPONSE']._serialized_end=291
  _globals['_LOCATEPRUNINGTIMESTAMP']._serialized_start=1340
  _globals['_LOCATEPRUNINGTIMESTAMP']._serialized_end=1467
  _globals['_LOCATEPRUNINGTIMESTAMP_REQUEST']._serialized_start=1366
  _globals['_LOCATEPRUNINGTIMESTAMP_REQUEST']._serialized_end=1397
  _globals['_LOCATEPRUNINGTIMESTAMP_RESPONSE']._serialized_start=1399
  _globals['_LOCATEPRUNINGTIMESTAMP_RESPONSE']._serialized_end=1467
  _globals['_SETNOWAITCOMMITMENTSFROM']._serialized_start=1470
  _globals['_SETNOWAITCOMMITMENTSFROM']._serialized_end=2060
  _globals['_SETNOWAITCOMMITMENTSFROM_REQUEST']._serialized_start=1499
  _globals['_SETNOWAITCOMMITMENTSFROM_REQUEST']._serialized_end=1742
  _globals['_SETNOWAITCOMMITMENTSFROM_RESPONSE']._serialized_start=1745
  _globals['_SETNOWAITCOMMITMENTSFROM_RESPONSE']._serialized_end=2060
  _globals['_SETNOWAITCOMMITMENTSFROM_RESPONSE_PARTICIPANTDOMAINSMAPPINGENTRY']._serialized_start=1932
  _globals['_SETNOWAITCOMMITMENTSFROM_RESPONSE_PARTICIPANTDOMAINSMAPPINGENTRY']._serialized_end=2060
  _globals['_RESETNOWAITCOMMITMENTSFROM']._serialized_start=2063
  _globals['_RESETNOWAITCOMMITMENTSFROM']._serialized_end=2511
  _globals['_RESETNOWAITCOMMITMENTSFROM_REQUEST']._serialized_start=2093
  _globals['_RESETNOWAITCOMMITMENTSFROM_REQUEST']._serialized_end=2191
  _globals['_RESETNOWAITCOMMITMENTSFROM_RESPONSE']._serialized_start=2194
  _globals['_RESETNOWAITCOMMITMENTSFROM_RESPONSE']._serialized_end=2511
  _globals['_RESETNOWAITCOMMITMENTSFROM_RESPONSE_PARTICIPANTDOMAINSMAPPINGENTRY']._serialized_start=1932
  _globals['_RESETNOWAITCOMMITMENTSFROM_RESPONSE_PARTICIPANTDOMAINSMAPPINGENTRY']._serialized_end=2060
  _globals['_DOMAINS']._serialized_start=2513
  _globals['_DOMAINS']._serialized_end=2553
  _globals['_GETNOWAITCOMMITMENTSFROM']._serialized_start=2556
  _globals['_GETNOWAITCOMMITMENTSFROM']._serialized_end=2921
  _globals['_GETNOWAITCOMMITMENTSFROM_REQUEST']._serialized_start=2584
  _globals['_GETNOWAITCOMMITMENTSFROM_REQUEST']._serialized_end=2667
  _globals['_GETNOWAITCOMMITMENTSFROM_RESPONSE']._serialized_start=2670
  _globals['_GETNOWAITCOMMITMENTSFROM_RESPONSE']._serialized_end=2921
  _globals['_NOWAITCOMMITMENTSSETUP']._serialized_start=2924
  _globals['_NOWAITCOMMITMENTSSETUP']._serialized_end=3364
  _globals['_WAITCOMMITMENTSSETUP']._serialized_start=3367
  _globals['_WAITCOMMITMENTSSETUP']._serialized_end=3653
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/daml/ledger/api/v2/admin/object_meta.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/daml/ledger/api/v2/admin/object_meta.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.com/daml/ledger/api/v2/admin/object_meta.proto\x12\x1c\x63om.daml.ledger.api.v2.admin\"\xd4\x01\n\nObjectMeta\x12)\n\x10resource_version\x18\x06 \x01(\tR\x0fresourceVersion\x12[\n\x0b\x61nnotations\x18\x0c \x03(\x0b\x32\x39.com.daml.ledger.api.v2.admin.ObjectMeta.AnnotationsEntryR\x0b\x61nnotations\x1a>\n\x10\x41nnotationsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\xa0\x01\n\x1c\x63om.daml.ledger.api.v2.adminB\x14ObjectMetaOuterClassZKgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2/admin\xaa\x02\x1c\x43om.Daml.Ledger.Api.V2.Adminb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.daml.ledger.api.v2.admin.object_meta_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034com.daml.ledger.api.v2.adminB\024ObjectMetaOuterClassZKgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2/admin\252\002\034Com.Daml.Ledger.Api.V2.Admin'
  _globals['_OBJECTMETA_ANNOTATIONSENTRY']._loaded_options = None
  _globals['_OBJECTMETA_ANNOTATIONSENTRY']._serialized_options = b'8\001'
  _globals['_OBJECTMETA']._serialized_start=81
  _globals['_OBJECTMETA']._serialized_end=293
  _globals['_OBJECTMETA_ANNOTATIONSENTRY']._serialized_start=231
  _globals['_OBJECTMETA_ANNOTATIONSENTRY']._serialized_end=293
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from ....protocol.v30 import sequencing_pb2 as _sequencing_pb2
from ....protocol.v30 import topology_pb2 as _topology_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SequencerConnect(_message.Message):
    __slots__ = ()
    class HandshakeRequest(_message.Message):
        __slots__ = ("handshake_request",)
        HANDSHAKE_REQUEST_FIELD_NUMBER: _ClassVar[int]
        handshake_request: _sequencing_pb2.Handshake.Request
        def __init__(self, handshake_request: _Optional[_Union[_sequencing_pb2.Handshake.Request, _Mapping]] = ...) -> None: ...
    class HandshakeResponse(_message.Message):
        __slots__ = ("handshake_response",)
        HANDSHAKE_RESPONSE_FIELD_NUMBER: _ClassVar[int]
        handshake_response: _sequencing_pb2.Handshake.Response
        def __init__(self, handshake_response: _Optional[_Union[_sequencing_pb2.Handshake.Response, _Mapping]] = ...) -> None: ...
    class GetDomainIdRequest(_message.Message):
        __slots__ = ()
        def __init__(self) -> None: ...
    class GetDomainIdResponse(_message.Message):
        __slots__ = ("domain_id", "sequencer_uid")
        DOMAIN_ID_FIELD_NUMBER: _ClassVar[int]
        SEQUENCER_UID_FIELD_NUMBER: _ClassVar[int]
        domain_id: str
        sequencer_uid: str
        def __init__(self, domain_id: _Optional[str] = ..., sequencer_uid: _Optional[str] = ...) -> None: ...
    class GetDomainParametersRequest(_message.Message):
        __slots__ = ()
        def __init__(self) -> None: ...
    class GetDomainParametersResponse(_message.Message):
        __slots__ = ("parameters_v1",)
        PARAMETERS_V1_FIELD_NUMBER: _ClassVar[int]
        parameters_v1: _sequencing_pb2.StaticDomainParameters
        def __init__(self, parameters_v1: _Optional[_Union[_sequencing_pb2.StaticDomainParameters, _Mapping]] = ...) -> None: ...
    class VerifyActiveRequest(_message.Message):
        __slots__ = ()
        def __init__(self) -> None: ...
    class VerifyActiveResponse(_message.Message):
        __slots__ = ("success", "failure")
        class Success(_message.Message):
            __slots__ = ("is_active",)
            IS_ACTIVE_FIELD_NUMBER: _ClassVar[int]
            is_active: bool
            def __init__(self, is_active: bool = ...) -> None: ...
        class Failure(_message.Message):
            __slots__ = ("reason",)
            REASON_FIELD_NUMBER: _ClassVar[int]
            reason: str
            def __init__(self, reason: _Optional[str] = ...) -> None: ...
        SUCCESS_FIELD_NUMBER: _ClassVar[int]
        FAILURE_FIELD_NUMBER: _ClassVar[int]
        success: SequencerConnect.VerifyActiveResponse.Success
        failure: SequencerConnect.VerifyActiveResponse.Failure
        def __init__(self, success: _Optional[_Union[SequencerConnect.VerifyActiveResponse.Success, _Mapping]] = ..., failure: _Optional[_Union[SequencerConnect.VerifyActiveResponse.Failure, _Mapping]] = ...) -> None: ...
    class RegisterOnboardingTopologyTransactionsRequest(_message.Message):
        __slots__ = ("topology_transactions",)
        TOPOLOGY_TRANSACTIONS_FIELD_NUMBER: _ClassVar[int]
        topology_transactions: _containers.RepeatedCompositeFieldContainer[_topology_pb2.SignedTopologyTransaction]
        def __init__(self, topology_transactions: _Optional[_Iterable[_Union[_topology_pb2.SignedTopologyTransaction, _Mapping]]] = ...) -> None: ...
    class RegisterOnboardingTopologyTransactionsResponse(_message.Message):
        __slots__ = ()
        def __init__(self) -> None: ...
    def __init__(self) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

from .common_stable_pb2 import AggregationRule, GlobalKey, SerializableContract
from .traffic_control_parameters_pb2 import SetTrafficPurchasedMessage, TrafficConsumed, TrafficControlParameters, TrafficPurchased, TrafficReceipt, TrafficState
from .sequencing_pb2 import Batch, CompressedBatch, Envelope, Handshake, PartySignatures, PossiblyIgnoredSequencedEvent, Recipients, RecipientsTree, SequencedEvent, SequencingSubmissionCost, ServiceAgreement, SinglePartySignatures, StaticDomainParameters, SubmissionRequest
from .domain_parameters_pb2 import AcsCommitmentsCatchUpConfig, DynamicDomainParameters, OnboardingRestriction, ParticipantDomainLimits
from .sequencing_parameters_pb2 import DynamicSequencingParameters
from .topology_pb2 import AuthorityOf, DecentralizedNamespaceDefinition, DomainParametersState, DomainTrustCertificate, DynamicSequencingParametersState, Enums, IdentifierDelegation, MediatorDomainState, NamespaceDelegation, OwnerToKeyMapping, ParticipantDomainPermission, PartyHostingLimits, PartyToKeyMapping, PartyToParticipant, PurgeTopologyTransaction, SequencerDomainState, SignedTopologyTransaction, TopologyMapping, TopologyTransaction, TopologyTransactionsBroadcast, VettedPackages
from .common_pb2 import DriverContractMetadata, ViewType
from .merkle_pb2 import BlindableNode, GenTransactionTree, MerkleSeq, MerkleSeqElement
from .quorum_pb2 import PartyIndexAndWeight, Quorum
from .participant_transaction_pb2 import ActionDescription, CommonMetadata, CreatedContract, DeduplicationPeriod, EncryptedViewMessage, FullInformeeTree, Informee, InformeeMessage, InputContract, LightTransactionViewTree, ParticipantMetadata, ParticipantRandomnessLookup, RootHashMessage, SessionKeyLookup, SubmitterMetadata, ViewCommonData, ViewNode, ViewParticipantData, ViewParticipantMessage
from .participant_transfer_pb2 import TransferId, TransferInCommonData, TransferInMediatorMessage, TransferInView, TransferOutCommonData, TransferOutMediatorMessage, TransferOutView, TransferSubmitterMetadata, TransferViewTree
from .acs_commitments_pb2 import AcsCommitment
from .confirmation_response_pb2 import ConfirmationResponse, LocalVerdict, MerkleSeqIndex, ViewPosition
from .mediator_pb2 import ConfirmationResultMessage, InformeeTree, MediatorReject, ParticipantReject, RejectionReason, Verdict
from .ordering_request_pb2 import OrderingRequest
from .signed_content_pb2 import SignedContent
from .storage_pb2 import StoredParties
from .synchronization_pb2 import EnvelopeContent, SignedProtocolMessage, TypedSignedProtocolMessageContent
from .versioned_google_rpc_status_pb2 import VersionedStatus

__all__ = [
    "AcsCommitment",
    "AcsCommitmentsCatchUpConfig",
    "ActionDescription",
    "AggregationRule",
    "AuthorityOf",
    "Batch",
    "BlindableNode",
    "CommonMetadata",
    "CompressedBatch",
    "ConfirmationResponse",
    "ConfirmationResultMessage",
    "CreatedContract",
    "DecentralizedNamespaceDefinition",
    "DeduplicationPeriod",
    "DomainParametersState",
    "DomainTrustCertificate",
    "DriverContractMetadata",
    "DynamicDomainParameters",
    "DynamicSequencingParameters",
    "DynamicSequencingParametersState",
    "EncryptedViewMessage",
    "Enums",
    "Envelope",
    "EnvelopeContent",
    "FullInformeeTree",
    "GenTransactionTree",
    "GlobalKey",
    "Handshake",
    "IdentifierDelegation",
    "Informee",
    "InformeeMessage",
    "InformeeTree",
    "InputContract",
    "LightTransactionViewTree",
    "LocalVerdict",
    "MediatorDomainState",
    "MediatorReject",
    "MerkleSeq",
    "MerkleSeqElement",
    "MerkleSeqIndex",
    "NamespaceDelegation",
    "OnboardingRestriction",
    "OrderingRequest",
    "OwnerToKeyMapping",
    "ParticipantDomainLimits",
    "ParticipantDomainPermission",
    "ParticipantMetadata",
    "ParticipantRandomnessLookup",
    "ParticipantReject",
    "PartyHostingLimits",
    "PartyIndexAndWeight",
    "PartySignatures",
    "PartyToKeyMapping",
    "PartyToParticipant",
    "PossiblyIgnoredSequencedEvent",
    "PurgeTopologyTransaction",
    "Quorum",
    "Recipients",
    "RecipientsTree",
    "RejectionReason",
    "RootHashMessage",
    "SequencedEvent",
    "SequencerDomainState",
    "SequencingSubmissionCost",
    "SerializableContract",
    "ServiceAgreement",
    "SessionKeyLookup",
    "SetTrafficPurchasedMessage",
    "SignedContent",
    "SignedProtocolMessage",
    "SignedTopologyTransaction",
    "SinglePartySignatures",
    "StaticDomainParameters",
    "StoredParties",
    "SubmissionRequest",
    "SubmitterMetadata",
    "TopologyMapping",
    "TopologyTransaction",
    "TopologyTransactionsBroadcast",
    "TrafficConsumed",
    "TrafficControlParameters",
    "TrafficPurchased",
    "TrafficReceipt",
    "TrafficState",
    "TransferId",
    "TransferInCommonData",
    "TransferInMediatorMessage",
    "TransferInView",
    "TransferOutCommonData",
    "TransferOutMediatorMessage",
    "TransferOutView",
    "TransferSubmitterMetadata",
    "TransferViewTree",
    "TypedSignedProtocolMessageContent",
    "Verdict",
    "VersionedStatus",
    "VettedPackages",
    "ViewCommonData",
    "ViewNode",
    "ViewParticipantData",
    "ViewParticipantMessage",
    "ViewPosition",
    "ViewType",
]



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from . import domain_connectivity_pb2 as com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_domain__connectivity__pb2

GRPC_GENERATED_VERSION = '1.67.1'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in com/digitalasset/canton/participant/admin/v0/domain_connectivity_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class DomainConnectivityServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ReconnectDomains = channel.unary_unary(
                '/com.digitalasset.canton.participant.admin.v0.DomainConnectivityService/ReconnectDomains',
                request_serializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_domain__connectivity__pb2.ReconnectDomainsRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_domain__connectivity__pb2.ReconnectDomainsResponse.FromString,
                _registered_method=True)
        self.RegisterDomain = channel.unary_unary(
                '/com.digitalasset.canton.participant.admin.v0.DomainConnectivityService/RegisterDomain',
                request_serializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_domain__connectivity__pb2.RegisterDomainRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_domain__connectivity__pb2.RegisterDomainResponse.FromString,
                _registered_method=True)
        self.ModifyDomain = channel.unary_unary(
                '/com.digitalasset.canton.participant.admin.v0.DomainConnectivityService/ModifyDomain',
                request_serializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_domain__connectivity__pb2.ModifyDomainRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_domain__connectivity__pb2.ModifyDomainResponse.FromString,
                _registered_method=True)
        self.ConnectDomain = channel.unary_unary(
                '/com.digitalasset.canton.participant.admin.v0.DomainConnectivityService/ConnectDomain',
                request_serializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_domain__connectivity__pb2.ConnectDomainRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_domain__connectivity__pb2.ConnectDomainResponse.FromString,
                _registered_method=True)
        self.DisconnectDomain = channel.unary_unary(
                '/com.digitalasset.canton.participant.admin.v0.DomainConnectivityService/DisconnectDomain',
                request_serializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_domain__connectivity__pb2.DisconnectDomainRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_domain__connectivity__pb2.DisconnectDomainResponse.FromString,
                _registered_method=True)
        self.ListConnectedDomains = channel.unary_unary(
                '/com.digitalasset.canton.participant.admin.v0.DomainConnectivityService/ListConnectedDomains',
                request_serializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_domain__connectivity__pb2.ListConnectedDomainsRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_domain__connectivity__pb2.ListConnectedDomainsResponse.FromString,
                _registered_method=True)
        self.ListConfiguredDomains = channel.unary_unary(
                '/com.digitalasset.canton.participant.admin.v0.DomainConnectivityService/ListConfiguredDomains',
                request_serializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_domain__connectivity__pb2.ListConfiguredDomainsRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_domain__connectivity__pb2.ListConfiguredDomainsResponse.FromString,
                _registered_method=True)
        self.GetAgreement = channel.unary_unary(
                '/com.digitalasset.canton.participant.admin.v0.DomainConnectivityService/GetAgreement',
                request_serializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_domain__connectivity__pb2.GetAgreementRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_domain__connectivity__pb2.GetAgreementResponse.FromString,
                _registered_method=True)
        self.AcceptAgreement = channel.unary_unary(
                '/com.digitalasset.canton.participant.admin.v0.DomainConnectivityService/AcceptAgreement',
                request_serializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_domain__connectivity__pb2.AcceptAgreementRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_domain__connectivity__pb2.AcceptAgreementResponse.FromString,
                _registered_method=True)
        self.GetDomainId = channel.unary_unary(
                '/com.digitalasset.canton.participant.admin.v0.DomainConnectivityService/GetDomainId',
                request_serializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_domain__connectivity__pb2.GetDomainIdRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_domain__connectivity__pb2.GetDomainIdResponse.FromString,
                _registered_method=True)


class DomainConnectivityServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ReconnectDomains(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterDomain(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ModifyDomain(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConnectDomain(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DisconnectDomain(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListConnectedDomains(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListConfiguredDomains(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAgreement(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AcceptAgreement(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDomainId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DomainConnectivityServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ReconnectDomains': grpc.unary_unary_rpc_method_handler(
                    servicer.ReconnectDomains,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_domain__connectivity__pb2.ReconnectDomainsRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_domain__connectivity__pb2.ReconnectDomainsResponse.SerializeToString,
            ),
            'RegisterDomain': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterDomain,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_domain__connectivity__pb2.RegisterDomainRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_domain__connectivity__pb2.RegisterDomainResponse.SerializeToString,
            ),
            'ModifyDomain': grpc.unary_unary_rpc_method_handler(
                    servicer.ModifyDomain,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_domain__connectivity__pb2.ModifyDomainRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_domain__connectivity__pb2.ModifyDomainResponse.SerializeToString,
            ),
            'ConnectDomain': grpc.unary_unary_rpc_method_handler(
                    servicer.ConnectDomain,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_domain__connectivity__pb2.ConnectDomainRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_domain__connectivity__pb2.ConnectDomainResponse.SerializeToString,
            ),
            'DisconnectDomain': grpc.unary_unary_rpc_method_handler(
                    servicer.DisconnectDomain,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_domain__connectivity__pb2.DisconnectDomainRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_domain__connectivity__pb2.DisconnectDomainResponse.SerializeToString,
            ),
            'ListConnectedDomains': grpc.unary_unary_rpc_method_handler(
                    servicer.ListConnectedDomains,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_domain__connectivity__pb2.ListConnectedDomainsRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_domain__connectivity__pb2.ListConnectedDomainsResponse.SerializeToString,
            ),
            'ListConfiguredDomains': grpc.unary_unary_rpc_method_handler(
                    servicer.ListConfiguredDomains,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_domain__connectivity__pb2.ListConfiguredDomainsRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_domain__connectivity__pb2.ListConfiguredDomainsResponse.SerializeToString,
            ),
            'GetAgreement': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAgreement,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_domain__connectivity__pb2.GetAgreementRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_domain__connectivity__pb2.GetAgreementResponse.SerializeToString,
            ),
            'AcceptAgreement': grpc.unary_unary_rpc_method_handler(
                    servicer.AcceptAgreement,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_domain__connectivity__pb2.AcceptAgreementRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_domain__connectivity__pb2.AcceptAgreementResponse.SerializeToString,
            ),
            'GetDomainId': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDomainId,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_domain__connectivity__pb2.GetDomainIdRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_domain__connectivity__pb2.GetDomainIdResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'com.digitalasset.canton.participant.admin.v0.DomainConnectivityService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('com.digitalasset.canton.participant.admin.v0.DomainConnectivityService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class DomainConnectivityService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ReconnectDomains(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.participant.admin.v0.DomainConnectivityService/ReconnectDomains',
            com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_domain__connectivity__pb2.ReconnectDomainsRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_domain__connectivity__pb2.ReconnectDomainsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RegisterDomain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.participant.admin.v0.DomainConnectivityService/RegisterDomain',
            com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_domain__connectivity__pb2.RegisterDomainRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_domain__connectivity__pb2.RegisterDomainResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ModifyDomain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.participant.admin.v0.DomainConnectivityService/ModifyDomain',
            com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_domain__connectivity__pb2.ModifyDomainRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_domain__connectivity__pb2.ModifyDomainResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ConnectDomain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.participant.admin.v0.DomainConnectivityService/ConnectDomain',
            com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_domain__connectivity__pb2.ConnectDomainRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_domain__connectivity__pb2.ConnectDomainResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DisconnectDomain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.participant.admin.v0.DomainConnectivityService/DisconnectDomain',
            com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_domain__connectivity__pb2.DisconnectDomainRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_domain__connectivity__pb2.DisconnectDomainResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListConnectedDomains(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.participant.admin.v0.DomainConnectivityService/ListConnectedDomains',
            com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_domain__connectivity__pb2.ListConnectedDomainsRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_domain__connectivity__pb2.ListConnectedDomainsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListConfiguredDomains(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.participant.admin.v0.DomainConnectivityService/ListConfiguredDomains',
            com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_domain__connectivity__pb2.ListConfiguredDomainsRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_domain__connectivity__pb2.ListConfiguredDomainsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetAgreement(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.participant.admin.v0.DomainConnectivityService/GetAgreement',
            com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_domain__connectivity__pb2.GetAgreementRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_domain__connectivity__pb2.GetAgreementResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AcceptAgreement(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.participant.admin.v0.DomainConnectivityService/AcceptAgreement',
            com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_domain__connectivity__pb2.AcceptAgreementRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_domain__connectivity__pb2.AcceptAgreementResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetDomainId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.participant.admin.v0.DomainConnectivityService/GetDomainId',
            com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_domain__connectivity__pb2.GetDomainIdRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_domain__connectivity__pb2.GetDomainIdResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ReassignmentCommand(_message.Message):
    __slots__ = ("workflow_id", "application_id", "command_id", "submitter", "unassign_command", "assign_command", "submission_id")
    WORKFLOW_ID_FIELD_NUMBER: _ClassVar[int]
    APPLICATION_ID_FIELD_NUMBER: _ClassVar[int]
    COMMAND_ID_FIELD_NUMBER: _ClassVar[int]
    SUBMITTER_FIELD_NUMBER: _ClassVar[int]
    UNASSIGN_COMMAND_FIELD_NUMBER: _ClassVar[int]
    ASSIGN_COMMAND_FIELD_NUMBER: _ClassVar[int]
    SUBMISSION_ID_FIELD_NUMBER: _ClassVar[int]
    workflow_id: str
    application_id: str
    command_id: str
    submitter: str
    unassign_command: UnassignCommand
    assign_command: AssignCommand
    submission_id: str
    def __init__(self, workflow_id: _Optional[str] = ..., application_id: _Optional[str] = ..., command_id: _Optional[str] = ..., submitter: _Optional[str] = ..., unassign_command: _Optional[_Union[UnassignCommand, _Mapping]] = ..., assign_command: _Optional[_Union[AssignCommand, _Mapping]] = ..., submission_id: _Optional[str] = ...) -> None: ...

class UnassignCommand(_message.Message):
    __slots__ = ("contract_id", "source", "target")
    CONTRACT_ID_FIELD_NUMBER: _ClassVar[int]
    SOURCE_FIELD_NUMBER: _ClassVar[int]
    TARGET_FIELD_NUMBER: _ClassVar[int]
    contract_id: str
    source: str
    target: str
    def __init__(self, contract_id: _Optional[str] = ..., source: _Optional[str] = ..., target: _Optional[str] = ...) -> None: ...

class AssignCommand(_message.Message):
    __slots__ = ("unassign_id", "source", "target")
    UNASSIGN_ID_FIELD_NUMBER: _ClassVar[int]
    SOURCE_FIELD_NUMBER: _ClassVar[int]
    TARGET_FIELD_NUMBER: _ClassVar[int]
    unassign_id: str
    source: str
    target: str
    def __init__(self, unassign_id: _Optional[str] = ..., source: _Optional[str] = ..., target: _Optional[str] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from . import party_management_service_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_party__management__service__pb2

GRPC_GENERATED_VERSION = '1.67.1'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in com/daml/ledger/api/v1/admin/party_management_service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class PartyManagementServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetParticipantId = channel.unary_unary(
                '/com.daml.ledger.api.v1.admin.PartyManagementService/GetParticipantId',
                request_serializer=com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_party__management__service__pb2.GetParticipantIdRequest.SerializeToString,
                response_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_party__management__service__pb2.GetParticipantIdResponse.FromString,
                _registered_method=True)
        self.GetParties = channel.unary_unary(
                '/com.daml.ledger.api.v1.admin.PartyManagementService/GetParties',
                request_serializer=com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_party__management__service__pb2.GetPartiesRequest.SerializeToString,
                response_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_party__management__service__pb2.GetPartiesResponse.FromString,
                _registered_method=True)
        self.ListKnownParties = channel.unary_unary(
                '/com.daml.ledger.api.v1.admin.PartyManagementService/ListKnownParties',
                request_serializer=com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_party__management__service__pb2.ListKnownPartiesRequest.SerializeToString,
                response_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_party__management__service__pb2.ListKnownPartiesResponse.FromString,
                _registered_method=True)
        self.AllocateParty = channel.unary_unary(
                '/com.daml.ledger.api.v1.admin.PartyManagementService/AllocateParty',
                request_serializer=com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_party__management__service__pb2.AllocatePartyRequest.SerializeToString,
                response_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_party__management__service__pb2.AllocatePartyResponse.FromString,
                _registered_method=True)
        self.UpdatePartyDetails = channel.unary_unary(
                '/com.daml.ledger.api.v1.admin.PartyManagementService/UpdatePartyDetails',
                request_serializer=com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_party__management__service__pb2.UpdatePartyDetailsRequest.SerializeToString,
                response_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_party__management__service__pb2.UpdatePartyDetailsResponse.FromString,
                _registered_method=True)
        self.UpdatePartyIdentityProviderId = channel.unary_unary(
                '/com.daml.ledger.api.v1.admin.PartyManagementService/UpdatePartyIdentityProviderId',
                request_serializer=com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_party__management__service__pb2.UpdatePartyIdentityProviderRequest.SerializeToString,
                response_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_party__management__service__pb2.UpdatePartyIdentityProviderResponse.FromString,
                _registered_method=True)


class PartyManagementServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetParticipantId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetParties(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListKnownParties(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AllocateParty(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdatePartyDetails(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdatePartyIdentityProviderId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PartyManagementServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetParticipantId': grpc.unary_unary_rpc_method_handler(
                    servicer.GetParticipantId,
                    request_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_party__management__service__pb2.GetParticipantIdRequest.FromString,
                    response_serializer=com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_party__management__service__pb2.GetParticipantIdResponse.SerializeToString,
            ),
            'GetParties': grpc.unary_unary_rpc_method_handler(
                    servicer.GetParties,
                    request_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_party__management__service__pb2.GetPartiesRequest.FromString,
                    response_serializer=com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_party__management__service__pb2.GetPartiesResponse.SerializeToString,
            ),
            'ListKnownParties': grpc.unary_unary_rpc_method_handler(
                    servicer.ListKnownParties,
                    request_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_party__management__service__pb2.ListKnownPartiesRequest.FromString,
                    response_serializer=com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_party__management__service__pb2.ListKnownPartiesResponse.SerializeToString,
            ),
            'AllocateParty': grpc.unary_unary_rpc_method_handler(
                    servicer.AllocateParty,
                    request_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_party__management__service__pb2.AllocatePartyRequest.FromString,
                    response_serializer=com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_party__management__service__pb2.AllocatePartyResponse.SerializeToString,
            ),
            'UpdatePartyDetails': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdatePartyDetails,
                    request_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_party__management__service__pb2.UpdatePartyDetailsRequest.FromString,
                    response_serializer=com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_party__management__service__pb2.UpdatePartyDetailsResponse.SerializeToString,
            ),
            'UpdatePartyIdentityProviderId': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdatePartyIdentityProviderId,
                    request_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_party__management__service__pb2.UpdatePartyIdentityProviderRequest.FromString,
                    response_serializer=com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_party__management__service__pb2.UpdatePartyIdentityProviderResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'com.daml.ledger.api.v1.admin.PartyManagementService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('com.daml.ledger.api.v1.admin.PartyManagementService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class PartyManagementService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetParticipantId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.daml.ledger.api.v1.admin.PartyManagementService/GetParticipantId',
            com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_party__management__service__pb2.GetParticipantIdRequest.SerializeToString,
            com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_party__management__service__pb2.GetParticipantIdResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetParties(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.daml.ledger.api.v1.admin.PartyManagementService/GetParties',
            com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_party__management__service__pb2.GetPartiesRequest.SerializeToString,
            com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_party__management__service__pb2.GetPartiesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListKnownParties(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.daml.ledger.api.v1.admin.PartyManagementService/ListKnownParties',
            com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_party__management__service__pb2.ListKnownPartiesRequest.SerializeToString,
            com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_party__management__service__pb2.ListKnownPartiesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AllocateParty(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.daml.ledger.api.v1.admin.PartyManagementService/AllocateParty',
            com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_party__management__service__pb2.AllocatePartyRequest.SerializeToString,
            com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_party__management__service__pb2.AllocatePartyResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdatePartyDetails(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.daml.ledger.api.v1.admin.PartyManagementService/UpdatePartyDetails',
            com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_party__management__service__pb2.UpdatePartyDetailsRequest.SerializeToString,
            com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_party__management__service__pb2.UpdatePartyDetailsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdatePartyIdentityProviderId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.daml.ledger.api.v1.admin.PartyManagementService/UpdatePartyIdentityProviderId',
            com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_party__management__service__pb2.UpdatePartyIdentityProviderRequest.SerializeToString,
            com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_party__management__service__pb2.UpdatePartyIdentityProviderResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
